@@ -17,20 +17,20 @@ cp_idf_matrix <- function(dtm, min_docfreq=1, max_docprob=1, min_obs_exp=0) {
   methods::as(simmat, 'dgCMatrix')
 }
 
-prepare_cp_lookup_matrix <- function(m, m2, id_from = c('m','m2','both')) {
+prepare_cp_lookup_matrix <- function(m, m2, idf_from = c('m','m2','both')) {
   if (identical(m,m2)) {
     simmat = cp_idf_matrix(m)
   } else {
-    if (id_from == 'm') {
+    if (idf_from == 'm') {
       simmat = cp_idf_matrix(m)  
     } else {
       terms = colnames(m)
       if (!identical(terms, colnames(m2))) 
         m2 = methods::as(reindexTerms(m2, terms), 'dgCMatrix')
       
-      if (id_from == 'both')
+      if (idf_from == 'both')
         simmat = cp_idf_matrix(rbind(m, m2))
-      if (id_from == 'm2')
+      if (idf_from == 'm2')
         simmat = cp_idf_matrix(m2)
       
       ## also filter out all term combinations that do not occur in m
@@ -41,45 +41,3 @@ prepare_cp_lookup_matrix <- function(m, m2, id_from = c('m','m2','both')) {
   }
   simmat
 }
-
-
-function() {
-  dtm = rnewsflow_dfm
-  #RNewsflow:::cp_idf_matrix(dtm[,1:10])
-  test = tcrossprod_sparse(dtm, min_value=0, crossfun = 'cp_lookup_norm', verbose=T)
-  test
-  max(test)
-  x = Matrix::rsparsematrix(10,10,0.1)
-  y = Matrix::rsparsematrix(10,10,0.1)
-  max(test)
-  hist(test@x)
-  length(test@x)
-  sum(cp_mat)
-  
-  n = 100
-  x = 5
-  y = 7
-  z = 2
-  xy = 5
-  xz = 1
-  
-  
-  
-  log(n/x)
-  log(n/y)
-  q = log(n/xy) - (log(n/x) + log(n/y))
-  
-  q + log(n/x) + log(n/y)
-  log(n/xy)
-  
-  
-  q1 = log(n/xy) - (log(n/x) + log(n/y))
-  q2 = log(n/xz) - (log(n/x) + log(n/z))
-  
-  log(n/x) + log(n/y) + log(n/z) + q1 + q2
-  
-  log(n/x) + log(n/y) + q1 + log(n/x) + log(n/z) + q2
-  
-  log(n/xy) + log(n/xz)
-  
-}
\ No newline at end of file
